(* Wolfram Language package *)


BeginPackage["QuantumAlgebra`Constants`", { "QuantumAlgebra`", "QuantumAlgebra`Options`", "QuantumAlgebra`Analyze`" }]

(* ::Section:: *)
(* Exported Symbols *)

\[Sigma]::usage =
	"Defines 3 Pauli matrices"

\[Gamma]::usage = 
	"Defines 4 Dirac matrices"


(* ::Section:: *)
(* Implementation of the Package *)

Begin["`Private`"]


Subscript[\[Sigma], 1] = {{0, 1}, {1, 0}};

Subscript[\[Sigma], 2] = {{0, -I}, {I, 0}};

Subscript[\[Sigma], 3] = {{1, 0}, {0, -1}};

id = {{1, 0}, {0, 1}};


defineDirac[pauli_List, pos1_List, pos2_List] :=
	Module[{dirac, insertAt},
		(* Internal Func inserts one matrix into another one *)
		insertAt[what_List, pos_List] := Part[dirac, pos[[1]] ;; pos[[1]] + 1, pos[[2]] ;; pos[[2]] + 1] = what;
	dirac=Table[0, {4}, {4}];
	insertAt[pauli, pos1];
	insertAt[-pauli, pos2];
	dirac]


Superscript[\[Gamma], 0] := defineDirac[id, {1, 1}, {3, 3}]

Superscript[\[Gamma], 1] := defineDirac[Subscript[\[Sigma], 1], {1, 3}, {3, 1}]

Superscript[\[Gamma], 2] := defineDirac[Subscript[\[Sigma], 2], {1, 3}, {3, 1}]

Superscript[\[Gamma], 3] := defineDirac[Subscript[\[Sigma],3], {1, 3}, {3, 1}]


End[]

EndPackage[]
