(* Mathematica package *)

BeginPackage["QuantumAlgebra`Options`"]



QAOptions::usage =
	"QAOptions[PrintLines->no] enables no lines of Print messages from Quantum Algebra, " <>
	"QAOptions[PrintLines->0] disables them. Initial state is disabled."

If[!ValueQ[PrintLines],
	PrintLines::usage = "The PrintLines option: 0 by default."
]

If[!ValueQ[PrintStack],
	PrintStack::usage = "The PrintStack option: None, Full, Recursive."
]

If[!ValueQ[StackPattern],
	StackPattern::usage = "The StackPattern option: None by default."
]

If[!ValueQ[DefinitionLevel],
	DefinitionLevel::usage = "The DefinitionLevel option: 3 by default."
]

If[!ValueQ[Recursive],
	Recursive::usage = "A value for the PrintStack option."
]


Begin["`Private`"]

(* ::Section:: *)
(* Region Print and Logging Support *)

Options[QAOptions] = 
{
	PrintLines -> 0,
	PrintStack -> None,
	StackPattern -> None,
	DefinitionLevel -> 3
}

QAOptions[OptionsPattern[]] :=
	SetOptions[
		QAOptions, 
		{ 
			PrintLines -> OptionValue[PrintLines],
			PrintStack -> OptionValue[PrintStack], 
			StackPattern -> OptionValue[StackPattern],
			DefinitionLevel -> OptionValue[DefinitionLevel] 
		}]

SetAttributes[QAPrint, { HoldAll }]

QAPrint[expr___] := QAPrint[1, expr]

QAPrint[lvl_Integer, expr___] := 
	Module[
		{
			pl = OptionValue[QAOptions, PrintLines],
			ps = OptionValue[QAOptions, PrintStack],
			sp = OptionValue[QAOptions, StackPattern],
			indent = StringJoin @@ Table["  ", lvl - 1],
			tr
		},
		tr = 
			Which[
				ps =!= None && sp === None, 
				Stack[], 
				ps =!= None, 
				Stack[sp]
			];
		If[pl > 0, 
			Print[indent, expr];
			pl--;
			Which[
				ps === Full,
				pl--; 
				Print[indent, "Stack: ", tr],
				ps === Recursive && Count[tr, Print] > 0,
				pl--;
				Print[indent, "Recursive Call: ", tr]
			];
			SetOptions[QAOptions, { PrintLines -> pl }];		 
		];
	]

(*****************************************************************************)

End[]

EndPackage[]
