(* Mathematica package *)
(* Created by the Wolfram Workbench 14.04.2016 *)


BeginPackage[
	"QuantumAlgebra`QuantumNotation`",
	{
		"QuantumAlgebra`",
		"Notation`"
	}
]
(* Exported symbols added here with SymbolName::usage *) 

SetQuantumNotation::usage =
	"SetQuantumNotation[] is used to permit input in Dirac Bra-Ket-Notation."

SetQuantumAliases::usage =
	"SetQuantumAliases[] sets keyboard aliases in the " <>
	"selected notebook. \nSetQuantumAliases[notebook] " <>
	"sets keyboard aliases in the specified notebook. " <>
	"The quantum aliases are keyboard key-combinations " <>
	"for the input of quantum objects in Dirac Notation."

SetQuantumAliases::aliases =
	"ALIASES:\n"<>
	"ESC op(du) ESC - Operator with or without indices\n"<>
	"ESC hop(du) ESC - Hermitian Operator with or without indices\n"<>
	"ESC ket(du) ESC - Ket with or without indices\n"<>
	"ESC (du)bra ESC - Bra with or without indices\n"<>
	"ESC (du)braket(du) ESC - BraKet with (left and / or right) subscript(s) and / or superscript(s).\n"<>
	"Letters in parenthesis signify optional indices (u - up, d - down) and must be given in that order.\n"<>
	"Example: use opd for an Operator with lower index."

SetNotationAliases::usage =
	"SetNotationAliases[nb] does the same as SetQuantumAliases[nb], see there."

SetBoxes::usage = 
	"SetBoxes[] is used to define proper structure of input / output boxes."

BraArgs::usage =
	"BraArgs is a tag for TagBoxes that guide the interpretation " <> 
	"of the internal structure of bra notation."

KetArgs::usage =
	"KetArgs is a tag for TagBoxes that guide the interpretation " <> 
	"of the internal structure of ket notation."

BraKetArgs::usage =
	"BraKetArgs is a tag for TagBoxes that guide the interpretation" <> 
	"of the internal structure of braket notation."

UDScript::usage =
	"UDScript is a tag for TagBoxes that guide the interpretation " <>  
	"of the internal structure of bras, kets, and brakets notation."

CloseNotationPalette::usage = "Closes the Notation Palette Notebook."

Begin["`Private`"]
(* Implementation of the package *)

SetQuantumNotation[doc_NotebookObject] :=
	Module[{},

		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{-0.4, 0}, {0, 0}}], 
			AdjustmentBox[
			TagBox["\[Psi]___",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], "\[RightAngleBracket]"}],
			Ket,
			BaseStyle->"KetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle",
			Editable->True]\) \[DoubleLongLeftRightArrow] \!\(\*
			TagBox[
			RowBox[{"Ket", "[", "\[Psi]___", "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle",
			Editable->True]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			TagBox["\[Psi]___",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], 
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{0, -0.2}, {0, 0}}]}],
			Bra,
			BaseStyle->"BraWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle",
			Editable->True]\) \[DoubleLongLeftRightArrow] \!\(\*
			TagBox[
			RowBox[{"Bra", "[", "\[Psi]___", "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle",
			Editable->True]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle",
			Editable->True]\) \[DoubleLongLeftRightArrow] \!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", "\[Psi]__", "}"}], ",", 
			RowBox[{"{", "\[Phi]__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle",
			Editable->True]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			SubscriptBox[
			RowBox[{
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{-0.4, 0}, {0, 0}}], 
			AdjustmentBox[
			TagBox["\[Psi]__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]],
			Ket,
			BaseStyle->"KetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Ket", "[", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			SuperscriptBox[
			RowBox[{
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{-0.4, 0}, {0, 0}}], 
			AdjustmentBox[
			TagBox["\[Psi]__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]],
			Ket,
			BaseStyle->"KetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Ket", "[", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "x__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			SubsuperscriptBox[
			RowBox[{
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{-0.4, 0}, {0, 0}}], 
			AdjustmentBox[
			TagBox["\[Psi]__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]],
			Ket,
			BaseStyle->"KetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Ket", "[", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x__", "}"}], ",", 
			RowBox[{"{", "y__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			TagBox["\[Psi]__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], 
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
			Bra,
			BaseStyle->"BraWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Bra", "[", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			TagBox["\[Psi]__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], 
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
			Bra,
			BaseStyle->"BraWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Bra", "[", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "x__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			TagBox["\[Psi]__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0], 
			AdjustmentBox["\[VerticalSeparator]",
			BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
			Bra,
			BaseStyle->"BraWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Bra", "[", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x__", "}"}], ",", 
			RowBox[{"{", "y__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			SubscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", "\[Psi]__", "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			SuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", "\[Psi]__", "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			TagBox[
			SubsuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			KetArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", "\[Psi]__", "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}], ",", 
			RowBox[{"{", "\[Phi]__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", "\[Phi]__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", "\[Phi]__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SubscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SubsuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SubscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SubsuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SubscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			TagBox[
			RowBox[{
			SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
			TagBox[
			AdjustmentBox[
			TagBox["x2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y2__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"LIndex"]], 
			SubsuperscriptBox[
			RowBox[{"\[LeftAngleBracket]", 
			AdjustmentBox[
			RowBox[{
			TagBox["\[Psi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
			TagBox["\[Phi]__",
			BraKetArgs,
			BaseStyle->"BraKetArg"]}],
			BoxBaselineShift->0], "\[RightAngleBracket]"}], 
			TagBox[
			AdjustmentBox[
			TagBox["x1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"], 
			TagBox[
			AdjustmentBox[
			TagBox["y1__",
			BraArgs,
			BaseStyle->"BraKetArg"],
			BoxBaselineShift->0],
			UDScript,
			BaseStyle->"RIndex"]]}],
			BraKet,
			BaseStyle->"BraKetWrapper"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"BraKet", "[", 
			RowBox[{
			RowBox[{"{", 
			RowBox[{"\[Psi]__", ",", 
			RowBox[{"{", "x2__", "}"}], ",", 
			RowBox[{"{", "y2__", "}"}]}], "}"}], ",", 
			RowBox[{"{", 
			RowBox[{"\[Phi]__", ",", 
			RowBox[{"{", "x1__", "}"}], ",", 
			RowBox[{"{", "y1__", "}"}]}], "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			SubscriptBox[
			RowBox[{"[", 
			RowBox[{"A_", ",", "B_"}], "]"}], "-"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Commutator", "[", 
			RowBox[{"A_", ",", "B_"}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*		
			TagBox[
			OverscriptBox["A_", "^"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", "A_", "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		Notation[\!\(\*
			TagBox[
			SuperscriptBox[
			OverscriptBox["x_", "^"], "n__"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"x_", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "n__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
			
		Notation[\!\(\*
			TagBox[
			SubscriptBox[
			OverscriptBox["x_", "^"], "m__"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"x_", ",", 
			RowBox[{"{", "m__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			SubsuperscriptBox[
			OverscriptBox["x_", "^"], "m__", "n__"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"x_", ",", 
			RowBox[{"{", "m__", "}"}], ",", 
			RowBox[{"{", "n__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];  
		
		Notation[\!\(\*
			TagBox[
			SubsuperscriptBox[
			OverscriptBox["A_", "^"], "x__", "\[Dagger]"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"A_", ",", "\"\<H\>\"", ",", 
			RowBox[{"{", "x__", "}"}], ",", 
			RowBox[{"{", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];  
		
		Notation[\!\(\*
			TagBox[
			SuperscriptBox[
			OverscriptBox["A_", "^"], "\[Dagger]"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"A_", ",", "\"\<H\>\""}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			SuperscriptBox[
			OverscriptBox["A_", "^"], 
			RowBox[{"y__", ",", "\[Dagger]"}]],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"A_", ",", "\"\<H\>\"", ",", 
			RowBox[{"{", "}"}], ",", 
			RowBox[{"{", "y__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];  
		
		Notation[\!\(\*
			TagBox[
			SubsuperscriptBox[
			OverscriptBox["A_", "^"], "x__", 
			RowBox[{"y__", ",", "\[Dagger]"}]],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Operator", "[", 
			RowBox[{"A_", ",", "\"\<H\>\"", ",", 
			RowBox[{"{", "x__", "}"}], ",", 
			RowBox[{"{", "y__", "}"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		  
		Notation[\!\(\*
			TagBox[
			SuperscriptBox[
			TagBox[
			RowBox[{"f_", "?", "AtomQ"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], "*"],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Conjugate", "[", 
			TagBox[
			RowBox[{"f_", "?", "AtomQ"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			RowBox[{
			SuperscriptBox[
			RowBox[{"(", 
			TagBox[
			RowBox[{"f_", "?", 
			RowBox[{"(", 
			RowBox[{
			RowBox[{"!", 
			RowBox[{"AtomQ", "[", "#", "]"}]}], "&"}], ")"}]}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], ")"}], "*"], " "}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Conjugate", "[", 
			TagBox[
			RowBox[{"f_", "?", 
			RowBox[{"(", 
			RowBox[{
			RowBox[{"!", 
			RowBox[{"AtomQ", "[", "#", "]"}]}], "&"}], ")"}]}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			SuperscriptBox[
			TagBox[
			RowBox[{"P_", "?", "OperatorQ"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], 
			TagBox[
			RowBox[{"n_", "?", "Negative"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"]],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Power", "[", 
			RowBox[{
			TagBox[
			RowBox[{"P_", "?", "OperatorQ"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], ",", 
			TagBox[
			RowBox[{"n_", "?", "Negative"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];
		
		Notation[\!\(\*
			TagBox[
			RowBox[{"c_", " ", 
			SuperscriptBox[
			TagBox[
			RowBox[{"P_", "?", "OperatorQ"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], 
			TagBox[
			RowBox[{"n_", "?", "Negative"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"]]}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\) \[DoubleLongLeftRightArrow] \
			\!\(\*
			TagBox[
			RowBox[{"Times", "[", 
			RowBox[{"c_", ",", 
			RowBox[{"Power", "[", 
			RowBox[{
			TagBox[
			RowBox[{"P_", "?", "OperatorQ"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"], ",", 
			TagBox[
			RowBox[{"n_", "?", "Negative"}],
			"NotationPatternTag",
			BaseStyle->"NotationPatternWrapperStyle"]}], "]"}]}], "]"}],
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\)
		];

		InfixNotation[\!\(\*
			TagBox["\[CenterDot]",
			"NotationTemplateTag",
			BaseStyle->"NotationTemplateStyle"]\), NonCommutativeMultiply
		];
		
		SetQuantumNotationSupplement[];
		
		True
	]

SetQuantumNotation[]:=
	Module[
		{nb},
		nb := InputNotebook[];
		If[nb == $Failed,
			Return[False]];
		SetQuantumNotation[nb]
	];


SetQuantumNotationSupplement[] :=
	Module[{},
		
		(* An Integral with one multidimensional integration variable *) 
		Notation[
			ParsedBoxWrapper[RowBox[{SubscriptBox["\[Integral]", "V_"], RowBox[{"ex_", RowBox[{SuperscriptBox["\[DifferentialD]", "n_"], "x_"}]}]}]] \[DoubleLongLeftRightArrow] 
			ParsedBoxWrapper[RowBox[{"QAIntegrate", "[", RowBox[{RowBox[{"(", "ex_", ")"}], ",", "V_", ",", "n_", ",", "x_"}], "]"}]]
		];		

		(* An Integral with two multidimensional integration variables of equal dimension *)
		Notation[
			ParsedBoxWrapper[RowBox[{SubscriptBox["\[Integral]", "V_"], RowBox[{"ex_", RowBox[{SuperscriptBox["\[DifferentialD]", "n_"], "x_"}], RowBox[{SuperscriptBox["\[DifferentialD]", "n_"], "y_"}]}]}]] \[DoubleLongLeftRightArrow] 
			ParsedBoxWrapper[RowBox[{"QAIntegrate", "[", RowBox[{RowBox[{"(", "ex_", ")"}], ",", "V_", ",", "n_", ",", "x_", ",", "y_"}], "]"}]]
		];

		(* A Sum with one or more summation indices *)
		Notation[
			ParsedBoxWrapper[RowBox[{UnderscriptBox["\[Sum]", "seq__"], "ex_"}]] \[DoubleLongLeftRightArrow] 
			ParsedBoxWrapper[RowBox[{"QASum", "[", RowBox[{"ex_", ",", "seq__"}], "]"}]]
		];

		(* A Product with one or more multiplication indices *)
		Notation[
			ParsedBoxWrapper[RowBox[{UnderscriptBox["\[Product]", "seq__"], "ex_"}]] \[DoubleLongLeftRightArrow] 
			ParsedBoxWrapper[RowBox[{"QAProduct", "[", RowBox[{"ex_", ",", "seq__"}], "]"}]]
		];

		(* A Derivation with one or more derivation variables *)
		Notation[
			ParsedBoxWrapper[RowBox[{SubscriptBox["\[GothicCapitalD]", "seq__"], "ex_"}]] \[DoubleLongLeftRightArrow] 
			ParsedBoxWrapper[RowBox[{"QAD", "[", RowBox[{"ex_", ",", "seq__"}], "]"}]]];

		(* A display notation for a Derivative operator *)
		Notation[
			ParsedBoxWrapper[SubscriptBox["\[PartialD]", "i_"]] \[DoubleLongLeftArrow] 
			ParsedBoxWrapper[RowBox[{"QAD", "[", RowBox[{"Subscript", "[", RowBox[{"x", ",", "i_"}], "]"}], "]"}]]];
		
		True
	];


(***** Input Aliases *****)
(***** keyboard aliases [ESC]alias[ESC] *****)

ClearAliases[] :=
	Module[
		{nb},
 		nb := InputNotebook[];
		If[nb == $Failed,
			Return[False]];
		ClearAliases[nb]
	];

ClearAliases[doc_NotebookObject] :=
	SetOptions[doc,InputAliases->{}];

SetNotationAliases[args___]:=
	SetQuantumAliases[args];

SetQuantumAliases[]:=
	Module[
		{nb},
		nb := InputNotebook[];
		If[nb == $Failed,
			Return[False]];
		SetQuantumAliases[nb]
	];

(*
	Implementation Remarks
	- the first implementation used SetOptions to set InputAliases
	- in the meantime we use AddInputAlias on the notebook document
	- this works better together with Notation to define Bra-Ket-Notation
	- an extra notebook defining those Aliases and Notations is no longer
	  required. 
*)
SetQuantumAliases[doc_NotebookObject]:=
	Module[
		{aliases},
    	ClearAliases[];
    	
    	aliases = 
    		{	(*
				"on" -> "\[CenterDot]",
				"tp" -> "\[CircleTimes]",
				*)
					
				"com" -> TagBox[
					SubscriptBox[
					RowBox[{"[", "\[SelectionPlaceholder]", "]"}], "-"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],

				"op" -> TagBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
				
				"hop" -> TagBox[
					SuperscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], "\[Dagger]"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
					
				(*	ADDED -> SEEMS TO WORK *)	
				"opd" -> TagBox[
					SubscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
					
				"opu" -> TagBox[
					SuperscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
					
				"opdu" -> TagBox[
					SubsuperscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]", "\[SelectionPlaceholder]"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
				
				"hopd" -> TagBox[
					SubsuperscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]", "\[Dagger]"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
				
				"hopu" -> TagBox[
					SuperscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], 
					RowBox[{"\[SelectionPlaceholder]", ",", "\[Dagger]"}]],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
				
				"hopdu" ->TagBox[
					SubsuperscriptBox[
					OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]", 
					RowBox[{"\[SelectionPlaceholder]", ",", "\[Dagger]"}]],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],

				"ket" -> TagBox[
					TagBox[
					RowBox[{
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{-0.4, 0}, {0, 0}}], 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], "\[RightAngleBracket]"}],
					Ket,
					BaseStyle->"KetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 

				"bra" -> TagBox[
					TagBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], 
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{0, -0.2}, {0, 0}}]}],
					Bra,
					BaseStyle->"BraWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 

				"braket" -> TagBox[
					TagBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 

				"ketd" -> TagBox[
					TagBox[
					SubscriptBox[
					RowBox[{
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{-0.4, 0}, {0, 0}}], 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]],
					Ket,
					BaseStyle->"KetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ketu" -> TagBox[
					TagBox[
					SuperscriptBox[
					RowBox[{
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{-0.4, 0}, {0, 0}}], 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]],
					Ket,
					BaseStyle->"KetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ketdu" -> TagBox[
					TagBox[
					SubsuperscriptBox[
					RowBox[{
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{-0.4, 0}, {0, 0}}], 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]],
					Ket,
					BaseStyle->"KetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dbra" -> TagBox[
					TagBox[
					RowBox[{
					SubscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], 
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
					Bra,
					BaseStyle->"BraWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ubra" -> TagBox[
					TagBox[
					RowBox[{
					SuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], 
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
					Bra,
					BaseStyle->"BraWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dubra" -> TagBox[
					TagBox[
					RowBox[{
					SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0], 
					AdjustmentBox["\[VerticalSeparator]",
					BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
					Bra,
					BaseStyle->"BraWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"braketu" -> TagBox[
					TagBox[
					SubscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"braketu" -> TagBox[
					TagBox[
					SuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"braketdu" -> TagBox[
					TagBox[
					SubsuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					KetArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dbraket" -> TagBox[
					TagBox[
					RowBox[{
					SubscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ubraket" -> TagBox[
					TagBox[
					RowBox[{
					SuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dubraket" -> TagBox[
					TagBox[
					RowBox[{
					SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dbraketd" -> TagBox[
					TagBox[
					RowBox[{
					SubscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SubscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dbraketu" -> TagBox[
					TagBox[
					RowBox[{
					SubscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dbraketdu" -> TagBox[
					TagBox[
					RowBox[{
					SubscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SubsuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ubraketd" -> TagBox[
					TagBox[
					RowBox[{
					SuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SubscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ubraketu" -> TagBox[
					TagBox[
					RowBox[{
					SuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"ubraketdu" -> TagBox[
					TagBox[
					RowBox[{
					SuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SubsuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"],
				
				"dubraketd" -> TagBox[
					TagBox[
					RowBox[{
					SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SubscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dubraketu" -> TagBox[
					TagBox[
					RowBox[{
					SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"], 
				
				"dubraketdu" -> TagBox[
					TagBox[
					RowBox[{
					SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"LIndex"]], 
					SubsuperscriptBox[
					RowBox[{"\[LeftAngleBracket]", 
					AdjustmentBox[
					RowBox[{
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
					TagBox["\[SelectionPlaceholder]",
					BraKetArgs,
					BaseStyle->"BraKetArg"]}],
					BoxBaselineShift->0], "\[RightAngleBracket]"}], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"], 
					TagBox[
					AdjustmentBox[
					TagBox["\[SelectionPlaceholder]",
					BraArgs,
					BaseStyle->"BraKetArg"],
					BoxBaselineShift->0],
					UDScript,
					BaseStyle->"RIndex"]]}],
					BraKet,
					BaseStyle->"BraKetWrapper"],
					"NotationTemplateTag",
					BaseStyle->"NotationTemplateStyle"] 
    		};

		Map[
			AddInputAlias[
				If[MatchQ[#, Rule[_, _TagBox]],
				# /. 
					((alias_ -> TagBox[box_, tag_, opt___]) -> 
					(alias -> ParsedBoxWrapper[box])),
				#],
				doc]&, 
			aliases];

		SetQuantumAliases::aliases
	];

SetBoxes[] :=
	Module[{nb},
		nb = InputNotebook[];
		If[nb == $Failed,
			Return[False]];
		Unprotect@SubscriptBox;
		SubscriptBox[RowBox[{x_, "[", RowBox[y_], "]"}], "-"] := 
			RowBox[{x, " ", SubscriptBox[RowBox[{"[", RowBox[y], "]"}], "-"]}];
		Protect@SubscriptBox;
		Unprotect@RowBox;
		RowBox[{"(", TagBox[arg_, Ket, opts___], ")"}] := 
			TagBox[arg, Ket, opts];
		RowBox[{"(", TagBox[arg_, Bra, `opts___], ")"}] := 
			TagBox[arg, Bra, opts];
		RowBox[{"(", TagBox[arg_, BraKet, opts___], ")"}] := 
			TagBox[ arg, BraKet, opts];
		Protect@RowBox;
		Unprotect@FullForm;
		FullForm /: TagBox[StyleBox[expr_, Verbatim[ShowSpecialCharacters -> False], rest__], FullForm] := 
			TagBox[StyleBox[expr, rest], FullForm];
		Protect@FullForm;	
		True	
	]

(* Closes the Notation Palette 
*)
CloseNotationPalette[] :=
	Module[{np},
		np = Notebooks["Notation Palette"];
		If[Length[np] == 1,
			NotebookClose[np // First]
		];
		True
	]
				

End[]

EndPackage[]
