(* Mathematica Test File *)

(* 0 Multiply *)
Test[
	0 ** Operator[A],
	Operator[0],
	TestID->"NonCommutativeMultiply-20160629-U5X3T0"
]

Test[
	Operator[A] ** 0,
	Operator[0],
	TestID->"NonCommutativeMultiply-20160629-Q9L0P0"
]

Test[
	0 ** Ket[A],
	0,
	TestID->"NonCommutativeMultiply-20160629-F4O8H5"
]

(* Operator[0] noncommutative multiply *)
Test[
	Operator[0] ** Operator[A],
	Operator[0],
	TestID->"NonCommutativeMultiply-20160629-I6J3B5"
]

Test[
	Operator[A] ** Operator[0],
	Operator[0],
	TestID->"NonCommutativeMultiply-20160629-V7Q6C1"
]

Test[
	Operator[0] ** Ket[A],
	0,
	TestID->"NonCommutativeMultiply-20160629-M8Y9J4"
]

(* Operator[0] add *)
Test[
	Operator[0] + Operator[A],
	Operator[A],
	TestID->"NonCommutativeMultiply-20160629-N6C7G8"
]

(*	TODO: This test is permitted by algebra rules but makes no sense :
	P not restricted to Operator
	-> possible improvement
*)
Test[
	Operator[0] + Ket[A],
	Ket[A],
	TestID->"NonCommutativeMultiply-20160629-H2S1H2"
]

(* Operator[0] multiply *)
Test[
	Operator[0] 4.5,
	0,
	TestID->"NonCommutativeMultiply-20160629-Q1L3T1"
]

(*	TODO: This test is permitted by algebra rules but makes no sense:
	c not restricted to Constant
	-> possible improvement
*)
Test[
	Operator[0] Ket[A],
	0,
	TestID->"NonCommutativeMultiply-20160629-I9W2L2"
]

(* Operator[1] noncommutative multiply *)
Test[
	Operator[1] ** Operator[A],
	Operator[A],
	TestID->"NonCommutativeMultiply-20160629-I2S4H7"
]

Test[
	Operator[A] ** Operator[1],
	Operator[A],
	TestID->"NonCommutativeMultiply-20160629-F5A4Z0"
]

Test[
	Operator[1] ** Ket[A],
	Ket[A],
	TestID->"NonCommutativeMultiply-20160629-I5D8A1"
]

(* Distributive Laws *)
Test[
	Operator[A] ** (Operator[B] + Operator[C]),
	Operator[A] ** Operator[B] + Operator[A] ** Operator[C],
	TestID->"NonCommutativeMultiply-20160629-L4Q4T2"
]

Test[
	(Operator[A] + Operator[B]) ** Operator[C],
	Operator[A] ** Operator[C] + Operator[B] ** Operator[C],
	TestID->"NonCommutativeMultiply-20160629-X7L1P9"
]

Test[
	Operator[A] ** (Ket[B] + Ket[C]),
	Operator[A] ** Ket[B] + Operator[A] ** Ket[C],
	TestID->"NonCommutativeMultiply-20160629-L7N0J5"
]

Test[
	(Operator[A] + Operator[B]) ** Ket[C],
	Operator[A] ** Ket[C] + Operator[B] ** Ket[C],
	TestID->"NonCommutativeMultiply-20160629-Q6T1Z9"
]

(* Multiplication with a Simple Constant ("Associative Law") *)
(*	TODO: Constant is normally applied using Times
	-> enforce stricter rules
	-> NONCOMMUTATIVE MULTIPLY : ADDED by me 
*)
Test[
	Operator[A] ** Pi ** Operator[B],
	Pi Operator[A] ** Operator[B],
	TestID->"NonCommutativeMultiply-20160629-I3D9H2"
]
Test[
	Pi ** Operator[A] ** Operator[B],
	Pi Operator[A] ** Operator[B],
	TestID->"NonCommutativeMultiply-20160629-U8C7L3"
]
Test[
	Operator[A] ** (Pi Operator[B]),
	Pi Operator[A] ** Operator[B],
	TestID->"NonCommutativeMultiply-20160629-D3A3K0"
]
Test[
	(BraKet[{m}, {n}] Operator[A]) ** Operator[B],
	BraKet[{m}, {n}] Operator[A] ** Operator[B],
	TestID->"NonCommutativeMultiply-20160629-J8A7I7"
]

(* Summation Rules : ADDED *)
Test[
	Operator[Q] ** Sum[Pi Ket[i], {i, 1, Infinity}],
	Sum[Pi Operator[Q] ** Ket[i], {i, 1, Infinity}],
	TestID->"NonCommutativeMultiply-20160629-P2D9O8"
]

Test[
	Sum[Pi Bra[i], {i, 1, Infinity}] ** Operator[Q],
	Sum[Pi Bra[i] ** Operator[Q], {i, 1, Infinity}],
	TestID->"NonCommutativeMultiply-20160629-U6F0L3"
]

(* Multiplication with Complex Constant : ADDED *)
Test[
	Ket[m] ** Bra[n] ** Exp[Operator[P]] ** Ket[n] ** Bra[m],
	Bra[n] ** Exp[Operator[P]] ** Ket[n] Ket[m] ** Bra[m],
	TestID->"NonCommutativeMultiply-20160629-S6G9N0"
]

Test[
	Bra[m] ** Bra[n] ** Exp[Operator[P]] ** Ket[n] ** Ket[m],
	Bra[n] ** Exp[Operator[P]] ** Ket[n] BraKet[{m}, {m}],
	TestID->"NonCommutativeMultiply-20160629-I8F9Q1"
]
