(* Wolfram Language Test file *)

(* Test of the Commutator Rule, Normal Ordering *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, {}];
	op2 = Operator[p, "H", { Subscript[l, 1], Subscript[l, 2] }, {}];
	(op1 ** op2) /. { DefineCommutatorRule[False, False, True, 2] }),
	(op2 ** op1) + DiscreteDelta[Subscript[l, 1] - Subscript[k, 1], Subscript[l, 2] - Subscript[k, 2]] Operator[1],
	TestID->"Exchange-20181226-W7C9S6"
]

(* Test of the Commutator Rule, Reverse Ordering *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, {}];
	op2 = Operator[p, "H", { Subscript[l, 1], Subscript[l, 2] }, {}];
	(op2 ** op1) /. { DefineCommutatorRule[False, False, False, 2] }),
	(op1 ** op2) - DiscreteDelta[Subscript[l, 1] - Subscript[k, 1], Subscript[l, 2] - Subscript[k, 2]] Operator[1],
	TestID->"Exchange-20181226-K2G1Y6"
]

(* Test of the Anti Commutator Rule, Normal Ordering *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, {}];
	op2 = Operator[p, "H", { Subscript[l, 1], Subscript[l, 2] }, {}];
	(op1 ** op2) /. { DefineCommutatorRule[True, False, True, 2] }),
	- (op2 ** op1) + DiscreteDelta[Subscript[l, 1] - Subscript[k, 1], Subscript[l, 2] - Subscript[k, 2]] Operator[1],
	TestID->"Exchange-20181226-J1P9F2"
]

(* Test of the Anti Commutator Rule, Reverse Ordering *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, { 1 }];
	op2 = Operator[p, "H", { Subscript[l, 1], Subscript[l, 2] }, { 1 }];
	(op2 ** op1) /. { DefineCommutatorRule[True, False, False, 2] }),
	- (op1 ** op2) + DiscreteDelta[Subscript[l, 1] - Subscript[k, 1], Subscript[l, 2] - Subscript[k, 2]] Operator[1],
	TestID->"Exchange-20181226-C5C3G1"
]

(* Test of the Commutator Rule, Normal Ordering *)
(* The same as above, but with different operator names *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, {}];
	op2 = Operator[q, "H", { Subscript[l, 1], Subscript[l, 2] }, {}];
	(op1 ** op2) /. { DefineCommutatorRule[False, False, True, 2] }),
	(op2 ** op1),
	TestID->"Exchange-20181226-B9M6B0"
]

(* Test of the Commutator Rule, Reverse Ordering *)
(* The same as above, but with different operator names *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, {}];
	op2 = Operator[q, "H", { Subscript[l, 1], Subscript[l, 2] }, {}];
	(op2 ** op1) /. { DefineCommutatorRule[False, False, False, 2] }),
	(op1 ** op2),
	TestID->"Exchange-20181226-C0G6I7"
]

(* Test of the Anti Commutator Rule, Normal Ordering *)
(* The same as above, but with different operator names *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, {}];
	op2 = Operator[q, "H", { Subscript[l, 1], Subscript[l, 2] }, {}];
	(op1 ** op2) /. { DefineCommutatorRule[True, False, True, 2] }),
	- (op2 ** op1),
	TestID->"Exchange-20181226-U2L6C8"
]

(* Test of the Anti Commutator Rule, Reverse Ordering *)
(* The same as above, but with different upper indices *)
Test[
	(op1 = Operator[p, { Subscript[k, 1], Subscript[k, 2] }, { 1 }];
	op2 = Operator[p, "H", { Subscript[l, 1], Subscript[l, 2] }, { 2 }];
	(op2 ** op1) /. { DefineCommutatorRule[True, False, False, 2] }),
	- (op1 ** op2),
	TestID->"Exchange-20181226-U0M3W9"
]
