(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     60460,       2138]
NotebookOptionsPosition[     48676,       1759]
NotebookOutlinePosition[     52319,       1843]
CellTagsIndexPosition[     52276,       1840]
WindowTitle->QuantumAlgebra Basics - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:QuantumAlgebra/guide/QuantumAlgebra"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["QUANTUM ALGEBRA PACKAGE TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"SetNotebookStyles\"\>":>
       Documentation`HelpLookup[
       "paclet:QuantumAlgebra/ref/SetNotebookStyles"], \
"\<\"BraKetBraKetOperator\"\>":>Documentation`HelpLookup[
       "paclet:QuantumAlgebra/ref/Bra"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"QuantumAlgebra/tutorial/QuantumAlgebraBasics\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["QuantumAlgebra/tutorial/QuantumAlgebraBasics"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/QuantumAlgebra/\
tutorial/QuantumAlgebraBasics.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "QuantumAlgebra/tutorial/QuantumAlgebraBasics", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 GridBoxOptions->{GridBoxItemSize->{"Columns" -> {
     Scaled[0.65], {
      Scaled[0.34]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
   "RowsIndexed" -> {}}},
 CellID->1],

Cell[CellGroupData[{

Cell["QuantumAlgebra Basics", "Title",
 CellID->509267359],

Cell["\<\
This tutorial introduces some of the basic principles how to enter Quantum \
objects and how to perform operations on them.\
\>", "Text",
 CellID->1534169418],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Preparation of a Session", "Section"]], "Subsection",
 CellID->65243614],

Cell["\<\
First one must load the QuantumAlgebra application by using the Needs command.\
\>", "Text",
 CellID->55229358],

Cell["This loads the package", "MathCaption",
 CellID->229374591],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QuantumAlgebra`\>\"", "]"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->379718389],

Cell[TextData[{
 "This command normally - in a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " front end session - loads the required context into the notebook. \
Additionally a few commands are performed to prepare the session. This \
includes the definition of notations and input aliases."
}], "Text",
 CellID->165222698],

Cell["\<\
You should invoke the command SetNotebookStyles[] once per Notebook. The \
required display styles are assigned to the notebook.\
\>", "Text",
 CellID->484100602],

Cell["\<\
After this is done, you are ready to input Quantum expressions and work with \
them.\
\>", "Text",
 CellID->520459910],

Cell["Sets required styles in the private style sheet", "MathCaption",
 CellID->437090803],

Cell[BoxData[
 RowBox[{"SetNotebookStyles", "[", "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->545952833],

Cell[BoxData[GridBox[{
   {
    RowBox[{"SetNotebookStyles", "[", "]"}], Cell[
    "Sets the required styles for proper display of objects", "TableText"]}
  }]], "DefinitionBox",
 CellID->2096742444],

Cell["Function Call to set Notebook Styles.", "Caption",
 CellID->369353387]
}, Open  ]],

Cell[CellGroupData[{

Cell["Provide Required Input", "Section",
 CellID->934999218],

Cell["\<\
After the session is prepared one can input Quantum objets and work with them.\
\>", "Text",
 CellID->313602936],

Cell["\<\
The basic Quantum objects supported by the package are Bra, Ket, BraKet, \
Operator.\
\>", "Text",
 CellID->156195064],

Cell["\<\
Supported input methods are the textual fullform input and the input by using \
the input aliases. By providing an input alias you can generate a \
2-dimensional template where the required information is to be placed in \
placeholders.\
\>", "Text",
 CellID->880376275],

Cell["\<\
Remark: Operators with indices can be entered in FullForm only.\
\>", "Text",
 CellID->147943834],

Cell[BoxData[GridBox[{
   {
    RowBox[{"Bra", "[", "m", "]"}], Cell[
    "Used to enter a Bra in FullForm", "TableText"]},
   {
    RowBox[{"Ket", "[", "n", "]"}], Cell[
    "Used to enter a Ket in FullForm", "TableText"]},
   {
    RowBox[{"BraKet", "[", 
     RowBox[{
      RowBox[{"{", "m", "}"}], ",", 
      RowBox[{"{", "n", "}"}]}], "]"}], Cell[
    "Used to enter a BraKet in FullForm", "TableText"]},
   {
    RowBox[{"Operator", "[", 
     RowBox[{"H", ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "j", "}"}]}], "]"}], 
    RowBox[{
     RowBox[{
     "Used", " ", "to", " ", "enter", " ", "an", " ", "Operator", " ", "in", 
      " ", "FullForm"}], ",", 
     RowBox[{"here", " ", "with", " ", "index"}]}]},
   {
    RowBox[{"Operator", "[", 
     RowBox[{"H", ",", "\"\<H\>\"", ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "]"}], 
    RowBox[{
    "Used", " ", "to", " ", "enter", " ", "an", " ", "Hermitian", " ", 
     "Operator"}]}
  }]], "DefinitionBox",
 CellID->502616482],

Cell["FullForm of Quantum Objects.", "Caption",
 CellID->433915648],

Cell["Input Aliases as printed out during Needs", "MathCaption",
 CellID->6003686],

Cell[BoxData["\<\"ALIASES:\\nESC op ESC - Operator without index\\nESC hop \
ESC - Hermitian Operator without index\\nESC ket ESC - Ket without \
index\\nESC ketd ESC - Ket with subscript(s)\\nESC ketu ESC - Ket with \
superscript(s)\\nESC ketdu ESC - Ket with subscript(s) & superscript(s)\\nESC \
bra ESC - Ket without index\\nESC dbra ESC - Bra with subscript(s)\\nESC ubra \
ESC - Bra with superscript(s)\\nESC dubra ESC - Bra with subscript(s) & \
superscript(s)\\nESC (du)braket(du) ESC - Bra with (left and / or right) \
subscript(s) and / or superscript(s).\"\>"], "Output",
 ImageSize->{390, 220},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->8336969],

Cell["Sample FullForm input - an Operator and a Ket", "MathCaption",
 CellID->836781195],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Operator", "[", 
  RowBox[{"V", ",", 
   RowBox[{"{", "i", "}"}], ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellID->9767984],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["V", "^"], "i"]], "Output",
 ImageSize->{19, 17},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->326111295]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ket", "[", 
  RowBox[{"m", ",", 
   RowBox[{"{", "i", "}"}], ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellID->295000522],

Cell[BoxData[
 TagBox[
  SubscriptBox[
   RowBox[{
    AdjustmentBox["\[VerticalSeparator]",
     BoxMargins->{{-0.4, 0}, {0, 0}}], 
    AdjustmentBox[
     TagBox["m",
      QuantumAlgebra`QuantumNotation`KetArgs,
      BaseStyle->"BraKetArg"],
     BoxBaselineShift->0], "\[RightAngleBracket]"}], 
   TagBox[
    AdjustmentBox[
     TagBox["i",
      QuantumAlgebra`QuantumNotation`KetArgs,
      BaseStyle->"BraKetArg"],
     BoxBaselineShift->0],
    QuantumAlgebra`QuantumNotation`UDScript,
    BaseStyle->"RIndex"]],
  Ket,
  BaseStyle->"KetWrapper"]], "Output",
 ImageSize->{40, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->176623231]
}, Open  ]],

Cell["\<\
Sample input with input alias - unfilled templates: a Bra and a BraKet\
\>", "MathCaption",
 CellID->473867497],

Cell[BoxData[
 TagBox[
  RowBox[{
   SuperscriptBox["\[InvisiblePrefixScriptBase]", 
    TagBox[
     AdjustmentBox[
      TagBox["\[Placeholder]",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"LIndex"]], 
   RowBox[{"\[LeftAngleBracket]", 
    AdjustmentBox[
     TagBox["\[SelectionPlaceholder]",
      QuantumAlgebra`QuantumNotation`BraArgs,
      BaseStyle->"BraKetArg"],
     BoxBaselineShift->0], 
    AdjustmentBox["\[VerticalSeparator]",
     BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
  Bra,
  BaseStyle->"BraWrapper"]], "Input",
 CellID->253465109],

Cell[BoxData[
 TagBox[
  RowBox[{
   SubscriptBox["\[InvisiblePrefixScriptBase]", 
    TagBox[
     AdjustmentBox[
      TagBox["\[Placeholder]",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"LIndex"]], 
   SubscriptBox[
    RowBox[{"\[LeftAngleBracket]", 
     AdjustmentBox[
      RowBox[{
       TagBox["\[SelectionPlaceholder]",
        QuantumAlgebra`QuantumNotation`BraKetArgs,
        BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
       TagBox["\[SelectionPlaceholder]",
        QuantumAlgebra`QuantumNotation`BraKetArgs,
        BaseStyle->"BraKetArg"]}],
      BoxBaselineShift->0], "\[RightAngleBracket]"}], 
    TagBox[
     AdjustmentBox[
      TagBox["\[SelectionPlaceholder]",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"RIndex"]]}],
  BraKet,
  BaseStyle->"BraKetWrapper"]], "Input",
 CellID->178066247],

Cell["Sample input with input alias - with information filled in", \
"MathCaption",
 CellID->56436755],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  RowBox[{
   SuperscriptBox["\[InvisiblePrefixScriptBase]", 
    TagBox[
     AdjustmentBox[
      TagBox["k",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"LIndex"]], 
   RowBox[{"\[LeftAngleBracket]", 
    AdjustmentBox[
     TagBox["n",
      QuantumAlgebra`QuantumNotation`BraArgs,
      BaseStyle->"BraKetArg"],
     BoxBaselineShift->0], 
    AdjustmentBox["\[VerticalSeparator]",
     BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
  Bra,
  BaseStyle->"BraWrapper"]], "Input",
 CellID->212963039],

Cell[BoxData[
 TagBox[
  RowBox[{
   SuperscriptBox["\[InvisiblePrefixScriptBase]", 
    TagBox[
     AdjustmentBox[
      TagBox["k",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"LIndex"]], 
   RowBox[{"\[LeftAngleBracket]", 
    AdjustmentBox[
     TagBox["n",
      QuantumAlgebra`QuantumNotation`BraArgs,
      BaseStyle->"BraKetArg"],
     BoxBaselineShift->0], 
    AdjustmentBox["\[VerticalSeparator]",
     BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
  Bra,
  BaseStyle->"BraWrapper"]], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->35879172]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  RowBox[{
   SubscriptBox["\[InvisiblePrefixScriptBase]", 
    TagBox[
     AdjustmentBox[
      TagBox["i",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"LIndex"]], 
   SubscriptBox[
    RowBox[{"\[LeftAngleBracket]", 
     AdjustmentBox[
      RowBox[{
       TagBox["m",
        QuantumAlgebra`QuantumNotation`BraKetArgs,
        BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
       TagBox["n",
        QuantumAlgebra`QuantumNotation`BraKetArgs,
        BaseStyle->"BraKetArg"]}],
      BoxBaselineShift->0], "\[RightAngleBracket]"}], 
    TagBox[
     AdjustmentBox[
      TagBox["j",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"RIndex"]]}],
  BraKet,
  BaseStyle->"BraKetWrapper"]], "Input",
 CellID->77836706],

Cell[BoxData[
 TagBox[
  RowBox[{
   SubscriptBox["\[InvisiblePrefixScriptBase]", 
    TagBox[
     AdjustmentBox[
      TagBox["i",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"LIndex"]], 
   SubscriptBox[
    RowBox[{"\[LeftAngleBracket]", 
     AdjustmentBox[
      RowBox[{
       TagBox["m",
        QuantumAlgebra`QuantumNotation`BraKetArgs,
        BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
       TagBox["n",
        QuantumAlgebra`QuantumNotation`BraKetArgs,
        BaseStyle->"BraKetArg"]}],
      BoxBaselineShift->0], "\[RightAngleBracket]"}], 
    TagBox[
     AdjustmentBox[
      TagBox["j",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"RIndex"]]}],
  BraKet,
  BaseStyle->"BraKetWrapper"]], "Output",
 ImageSize->{60, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellID->17954646]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Few Simple Calculations", "Section",
 CellID->587363850],

Cell["\<\
This section demonstrates in a few simple samples, how calculations can be \
done in QuantumAlgebra.\
\>", "Text",
 CellID->374249813],

Cell[CellGroupData[{

Cell["Orthonormalized BraKet Sample", "Subsection",
 CellID->33620847],

Cell["\<\
The first sample demonstrates, how a BraKet can be assigned a function to \
calculate its value and what the result multiplying a Bra and a Ket then is.\
\>", "Text",
 CellID->735022179],

Cell[BoxData[GridBox[{
   {"CenterDot", 
    RowBox[{
    "Used", " ", "to", " ", "multiply", " ", "Bra", " ", "and", " ", "Ket", 
     " ", 
     RowBox[{"(", 
      RowBox[{"Alias", ":", " ", 
       RowBox[{"ESC", " ", ".", " ", "ESC"}]}], ")"}]}]}
  }]], "DefinitionBox",
 CellID->358456651],

Cell["\<\
Multiplication Operator to concatenate Bras, Kets and (optionally) Operators.\
\>", "Caption",
 CellID->1891092685],

Cell["Definition and Usage of BraKets", "MathCaption",
 CellID->169278472],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Orthonormalized", " ", "BraKet"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[InvisiblePrefixScriptBase]", 
      TagBox[
       AdjustmentBox[
        TagBox["i_",
         QuantumAlgebra`QuantumNotation`BraArgs,
         BaseStyle->"BraKetArg"],
        BoxBaselineShift->0],
       QuantumAlgebra`QuantumNotation`UDScript,
       BaseStyle->"LIndex"]], 
     SubscriptBox[
      RowBox[{"\[LeftAngleBracket]", 
       AdjustmentBox[
        RowBox[{
         TagBox["m_",
          QuantumAlgebra`QuantumNotation`BraKetArgs,
          BaseStyle->"BraKetArg"], "\[VerticalSeparator]", 
         TagBox["n_",
          QuantumAlgebra`QuantumNotation`BraKetArgs,
          BaseStyle->"BraKetArg"]}],
        BoxBaselineShift->0], "\[RightAngleBracket]"}], 
      TagBox[
       AdjustmentBox[
        TagBox["j_",
         QuantumAlgebra`QuantumNotation`BraArgs,
         BaseStyle->"BraKetArg"],
        BoxBaselineShift->0],
       QuantumAlgebra`QuantumNotation`UDScript,
       BaseStyle->"RIndex"]]}],
    BraKet,
    BaseStyle->"BraKetWrapper"], ":=", 
   RowBox[{
    RowBox[{"KroneckerDelta", "[", 
     RowBox[{"i", ",", "j"}], "]"}], " ", 
    RowBox[{"KroneckerDelta", "[", 
     RowBox[{"m", ",", "n"}], "]"}]}]}]}]], "Input",
 CellLabel->"In[31]:=",
 CellID->223821793],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Equal", " ", "indices", " ", "and", " ", "labels", " ", "yield", " ", 
    "1"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[InvisiblePrefixScriptBase]", 
      TagBox[
       AdjustmentBox[
        TagBox["1",
         QuantumAlgebra`QuantumNotation`BraArgs,
         BaseStyle->"BraKetArg"],
        BoxBaselineShift->0],
       QuantumAlgebra`QuantumNotation`UDScript,
       BaseStyle->"LIndex"]], 
     RowBox[{"\[LeftAngleBracket]", 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`BraArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], 
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
    Bra,
    BaseStyle->"BraWrapper"], "\[CenterDot]", 
   TagBox[
    SubscriptBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox["1",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0],
      QuantumAlgebra`QuantumNotation`UDScript,
      BaseStyle->"RIndex"]],
    Ket,
    BaseStyle->"KetWrapper"]}]}]], "Input",
 CellLabel->"In[32]:=",
 CellID->628528297],

Cell[BoxData["1"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[32]=",
 CellID->19540070]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    SubscriptBox["\[InvisiblePrefixScriptBase]", 
     TagBox[
      AdjustmentBox[
       TagBox["j",
        QuantumAlgebra`QuantumNotation`BraArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0],
      QuantumAlgebra`QuantumNotation`UDScript,
      BaseStyle->"LIndex"]], 
    RowBox[{"\[LeftAngleBracket]", 
     AdjustmentBox[
      TagBox["2",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0], 
     AdjustmentBox["\[VerticalSeparator]",
      BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
   Bra,
   BaseStyle->"BraWrapper"], "\[CenterDot]", 
  TagBox[
   SubscriptBox[
    RowBox[{
     AdjustmentBox["\[VerticalSeparator]",
      BoxMargins->{{-0.4, 0}, {0, 0}}], 
     AdjustmentBox[
      TagBox["2",
       QuantumAlgebra`QuantumNotation`KetArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0], "\[RightAngleBracket]"}], 
    TagBox[
     AdjustmentBox[
      TagBox["j",
       QuantumAlgebra`QuantumNotation`KetArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"RIndex"]],
   Ket,
   BaseStyle->"KetWrapper"]}]], "Input",
 CellLabel->"In[33]:=",
 CellID->829276182],

Cell[BoxData["1"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[33]=",
 CellID->356632697]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Else", " ", "yields", " ", "0"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[InvisiblePrefixScriptBase]", 
      TagBox[
       AdjustmentBox[
        TagBox["2",
         QuantumAlgebra`QuantumNotation`BraArgs,
         BaseStyle->"BraKetArg"],
        BoxBaselineShift->0],
       QuantumAlgebra`QuantumNotation`UDScript,
       BaseStyle->"LIndex"]], 
     RowBox[{"\[LeftAngleBracket]", 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`BraArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], 
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
    Bra,
    BaseStyle->"BraWrapper"], "\[CenterDot]", 
   TagBox[
    SubscriptBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox["3",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0],
      QuantumAlgebra`QuantumNotation`UDScript,
      BaseStyle->"RIndex"]],
    Ket,
    BaseStyle->"KetWrapper"]}]}]], "Input",
 CellLabel->"In[34]:=",
 CellID->528025387],

Cell[BoxData["0"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",
 CellID->209030887]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    SubscriptBox["\[InvisiblePrefixScriptBase]", 
     TagBox[
      AdjustmentBox[
       TagBox["3",
        QuantumAlgebra`QuantumNotation`BraArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0],
      QuantumAlgebra`QuantumNotation`UDScript,
      BaseStyle->"LIndex"]], 
    RowBox[{"\[LeftAngleBracket]", 
     AdjustmentBox[
      TagBox["5",
       QuantumAlgebra`QuantumNotation`BraArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0], 
     AdjustmentBox["\[VerticalSeparator]",
      BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
   Bra,
   BaseStyle->"BraWrapper"], "\[CenterDot]", 
  TagBox[
   SubscriptBox[
    RowBox[{
     AdjustmentBox["\[VerticalSeparator]",
      BoxMargins->{{-0.4, 0}, {0, 0}}], 
     AdjustmentBox[
      TagBox["4",
       QuantumAlgebra`QuantumNotation`KetArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0], "\[RightAngleBracket]"}], 
    TagBox[
     AdjustmentBox[
      TagBox["3",
       QuantumAlgebra`QuantumNotation`KetArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0],
     QuantumAlgebra`QuantumNotation`UDScript,
     BaseStyle->"RIndex"]],
   Ket,
   BaseStyle->"KetWrapper"]}]], "Input",
 CellLabel->"In[35]:=",
 CellID->693483989],

Cell[BoxData["0"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[35]=",
 CellID->391276511]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Different", " ", "symbols"}], " ", "-", " ", 
    RowBox[{
    "Mathematica", " ", "cannot", " ", "make", " ", "assertions", " ", 
     "about", " ", "equality"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["\[InvisiblePrefixScriptBase]", 
      TagBox[
       AdjustmentBox[
        TagBox["j",
         QuantumAlgebra`QuantumNotation`BraArgs,
         BaseStyle->"BraKetArg"],
        BoxBaselineShift->0],
       QuantumAlgebra`QuantumNotation`UDScript,
       BaseStyle->"LIndex"]], 
     RowBox[{"\[LeftAngleBracket]", 
      AdjustmentBox[
       TagBox["k",
        QuantumAlgebra`QuantumNotation`BraArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], 
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{0, -0.2}, {0, 0}}]}]}],
    Bra,
    BaseStyle->"BraWrapper"], "\[CenterDot]", 
   TagBox[
    SubscriptBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["l",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox["j",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0],
      QuantumAlgebra`QuantumNotation`UDScript,
      BaseStyle->"RIndex"]],
    Ket,
    BaseStyle->"KetWrapper"]}]}]], "Input",
 CellLabel->"In[36]:=",
 CellID->597996886],

Cell[BoxData[
 RowBox[{"KroneckerDelta", "[", 
  RowBox[{"k", ",", "l"}], "]"}]], "Output",
 ImageSize->{141, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[36]=",
 CellID->22716009]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Harmonic Oscillator Sample", "Subsection",
 CellID->30976998],

Cell["\<\
The Quantum Mechanical Oscillator is one of the most important yet simple \
systems in Quantum Theory. We try to demonstrate the application of Quantum \
Algebra to analyze and calculate this system.\
\>", "Text",
 CellID->415773475],

Cell["\<\
First we define a simplification function, which can be used as appropriate.\
\>", "Text",
 CellID->862903444],

Cell[BoxData[GridBox[{
   {"QASet", Cell["Defines the given rule and derived rules.", "TableText"]},
   {"QACommutatorExpand", Cell[
    "Replaces Commutators by their definition.", "TableText"]},
   {"QAExpandAll", Cell["Combines some expand functions of QA.", "TableText"]}
  }]], "DefinitionBox",
 CellID->151152663],

Cell["A few functions used in this example.", "Caption",
 CellID->99518789],

Cell["A simplification function making assumptions", "MathCaption",
 CellID->285879248],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplifyAss", "[", "exp_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"exp", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"m", ">", "0"}], "&&", 
        RowBox[{"\[HBar]", ">", "0"}], "&&", 
        RowBox[{"\[Omega]", ">", "0"}]}]}]}], "]"}], "//", "Expand"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->459423626],

Cell["\<\
Next we define the Quantum Mechanical Oscillator by introducing its \
Hamiltonian. Then we define the important Commutation relation for Location \
and Momentum Operators. Finally we define the Location and Momentum Operators \
as Hermitian.\
\>", "Text",
 CellID->224802088],

Cell["Hamiltonian, Commutation Relations and Hermitian", "MathCaption",
 CellID->190116851],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Hamilton", " ", "Operator", " ", "defined", " ", "in", " ", "terms", " ", 
   "of", " ", "Location", " ", "and", " ", "Momentum", " ", "Operator"}], " ",
   "*)"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->95552490],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["H", "^"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "2"}], "/", "m"}], " ", 
    RowBox[{
     OverscriptBox["p", "^"], "^", "2"}]}], "+", 
   RowBox[{"m", " ", 
    RowBox[{
     RowBox[{"\[Omega]", "^", "2"}], "/", "2"}], " ", 
    RowBox[{
     OverscriptBox["x", "^"], "^", "2"}]}]}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->275423488],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox[
    OverscriptBox["p", "^"], "2"], 
   RowBox[{"2", " ", "m"}]], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "m", " ", 
   SuperscriptBox["\[Omega]", "2"], " ", 
   SuperscriptBox[
    OverscriptBox["x", "^"], "2"]}]}]], "Output",
 ImageSize->{94, 37},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->18531809]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Defines", " ", "the", " ", "Commutation", " ", "Relation", " ", "between", 
   " ", "Location", " ", "and", " ", "Momentum"}], " ", "*)"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->21827284],

Cell[BoxData[
 RowBox[{"QASet", "[", 
  RowBox[{
   SubscriptBox[
    RowBox[{"[", 
     RowBox[{
      OverscriptBox["x", "^"], ",", 
      OverscriptBox["p", "^"]}], "]"}], "-"], "=", 
   RowBox[{"\[ImaginaryI]", " ", "\[HBar]", " ", 
    OverscriptBox["1", "^"]}]}], "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->218097565],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Location", " ", "Operator", " ", 
   OverscriptBox["x", "^"], " ", "is", " ", "Hermitian"}], " ", 
  "*)"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->75068386],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   OverscriptBox["x", "^"], "\[Dagger]"], "=", 
  OverscriptBox["x", "^"]}]], "Input",
 CellLabel->"In[9]:=",
 CellID->64153344],

Cell[BoxData[
 OverscriptBox["x", "^"]], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->10298058]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "The", " ", "same", " ", "yields", " ", "true", " ", "for", " ", "the", " ",
    "Momentum", " ", "Operator", " ", 
   OverscriptBox["p", "^"]}], " ", "*)"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->191018353],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   OverscriptBox["p", "^"], "\[Dagger]"], "=", 
  OverscriptBox["p", "^"]}]], "Input",
 CellLabel->"In[11]:=",
 CellID->498544831],

Cell[BoxData[
 OverscriptBox["p", "^"]], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->54067020]
}, Open  ]],

Cell[TextData[{
 "Next we introduce a few rules. They are all based on the definition of the \
so called Creation Operator and its counter part - the Annihilation Operator. \
Whereas Rule 1 can substitute Annihilation and Creation Operators by Location \
and Momentum, Rule 2 can do the opposite. Rules 3 and 4 are rules derived \
from Commutator definition for the Annihilation and Creation Operators. Rules \
5 and 6 introduce the so called Number Operator ",
 Cell[BoxData[
  OverscriptBox["N", "^"]]],
 ". "
}], "Text",
 CellID->232292278],

Cell["Definition of required rules", "MathCaption",
 CellID->323211167],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "We", " ", "define", " ", "rules", " ", "where", " ", "a", " ", 
   "Commutator", " ", "definition", " ", "is", " ", "solved", " ", "after", 
   " ", "one", " ", "of", " ", "the", " ", "both", " ", "products", " ", "of",
    " ", "the", " ", "contributing", " ", "Operators"}], " ", "*)"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->717936233],

Cell[BoxData[
 RowBox[{
  RowBox[{"commutatorRules", "[", 
   RowBox[{"op1_Operator", ",", "op2_Operator"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"commutator", "=", 
       SubscriptBox[
        RowBox[{"[", 
         RowBox[{"op1", ",", "op2"}], "]"}], "-"]}], ",", "rule1", ",", 
      "rule2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rule1", "=", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"commutator", "\[Equal]", 
         RowBox[{"(", 
          RowBox[{"commutator", "//", "QACommutatorExpand"}], ")"}]}], ",", 
        RowBox[{"op1", "\[CenterDot]", "op2"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rule2", "=", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"commutator", "\[Equal]", 
         RowBox[{"(", 
          RowBox[{"commutator", "//", "QACommutatorExpand"}], ")"}]}], ",", 
        RowBox[{"op2", "\[CenterDot]", "op1"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"rule1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"rule2", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->"In[15]:=",
 CellID->322602097],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "From", " ", "our", " ", "start", " ", "rule", " ", "we", " ", "derive", 
   " ", "a", " ", "second", " ", "rule", " ", "by", " ", "Hermitian", " ", 
   "operation", " ", "and", " ", "unify", " ", "them", " ", "in", " ", "a", 
   " ", "List"}], " ", "*)"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[16]:=",
 CellID->51631347],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule1", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"rule", ",", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Hermitian", "[", "#", "]"}], "&"}], ",", "rule"}], "]"}]}], 
    "}"}], "//", "FullSimplifyAss"}]}]], "Input",
 CellLabel->"In[17]:=",
 CellID->354816522],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        OverscriptBox["p", "^"]}], 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox["m"], " ", 
        SqrtBox["\[Omega]"], " ", 
        SqrtBox["\[HBar]"]}]]}], "+", 
     FractionBox[
      RowBox[{
       SqrtBox["m"], " ", 
       SqrtBox["\[Omega]"], " ", 
       OverscriptBox["x", "^"]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["\[HBar]"]}]]}]}], ",", 
   RowBox[{
    OverscriptBox["a", "^"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       OverscriptBox["p", "^"]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["m"], " ", 
       SqrtBox["\[Omega]"], " ", 
       SqrtBox["\[HBar]"]}]], "+", 
     FractionBox[
      RowBox[{
       SqrtBox["m"], " ", 
       SqrtBox["\[Omega]"], " ", 
       OverscriptBox["x", "^"]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["\[HBar]"]}]]}]}]}], "}"}]], "Output",
 ImageSize->{446, 41},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->147246005]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Rule", " ", "2", " ", "solves", " ", "the", " ", "rules", " ", "in", " ", 
   "Rule", " ", "1", " ", "after", " ", "Location", " ", "and", " ", 
   "Momentum", " ", "operators"}], " ", "*)"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->13352499],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"rule1", "/.", 
       RowBox[{"Rule", "\[Rule]", "Equal"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox["x", "^"], ",", 
        OverscriptBox["p", "^"]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplifyAss"}]}]], "Input",
 CellLabel->"In[19]:=",
 CellID->117576209],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    OverscriptBox["x", "^"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SqrtBox["\[HBar]"], " ", 
       OverscriptBox["a", "^"]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["m"], " ", 
       SqrtBox["\[Omega]"]}]], "+", 
     FractionBox[
      RowBox[{
       SqrtBox["\[HBar]"], " ", 
       SuperscriptBox[
        OverscriptBox["a", "^"], "\[Dagger]"]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["m"], " ", 
       SqrtBox["\[Omega]"]}]]}]}], ",", 
   RowBox[{
    OverscriptBox["p", "^"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["m"], " ", 
        SqrtBox["\[Omega]"], " ", 
        SqrtBox["\[HBar]"], " ", 
        OverscriptBox["a", "^"]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["m"], " ", 
       SqrtBox["\[Omega]"], " ", 
       SqrtBox["\[HBar]"], " ", 
       SuperscriptBox[
        OverscriptBox["a", "^"], "\[Dagger]"]}], 
      SqrtBox["2"]]}]}]}], "}"}]], "Output",
 ImageSize->{466, 41},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[19]=",
 CellID->32445800]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "From", " ", "the", " ", "commutatorRules", " ", "derives", " ", "rules", 
   " ", "for", " ", "Creation", " ", "and", " ", "Annihilation", " ", 
   "Operator"}], " ", "*)"}]], "Input",
 CellLabel->"In[20]:=",
 CellID->220241553],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule3", "=", 
  RowBox[{
   RowBox[{"commutatorRules", "[", 
    RowBox[{
     OverscriptBox["a", "^"], ",", 
     SuperscriptBox[
      OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellLabel->"In[21]:=",
 CellID->545649329],

Cell[BoxData[
 RowBox[{
  RowBox[{
   OverscriptBox["a", "^"], "\[CenterDot]", 
   SuperscriptBox[
    OverscriptBox["a", "^"], "\[Dagger]"]}], "\[Rule]", 
  RowBox[{
   SubscriptBox[
    RowBox[{"[", 
     RowBox[{
      OverscriptBox["a", "^"], ",", 
      SuperscriptBox[
       OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "-"], "+", 
   RowBox[{
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
    OverscriptBox["a", "^"]}]}]}]], "Output",
 ImageSize->{147, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[21]=",
 CellID->95657832]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule4", "=", 
  RowBox[{
   RowBox[{"commutatorRules", "[", 
    RowBox[{
     OverscriptBox["a", "^"], ",", 
     SuperscriptBox[
      OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellLabel->"In[22]:=",
 CellID->24585273],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
   OverscriptBox["a", "^"]}], "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    SubscriptBox[
     RowBox[{"[", 
      RowBox[{
       OverscriptBox["a", "^"], ",", 
       SuperscriptBox[
        OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "-"]}], "+", 
   RowBox[{
    OverscriptBox["a", "^"], "\[CenterDot]", 
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"]}]}]}]], "Output",
 ImageSize->{155, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[22]=",
 CellID->480176075]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule5", "=", 
  RowBox[{
   OverscriptBox["N", "^"], "\[Rule]", 
   RowBox[{
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
    OverscriptBox["a", "^"]}]}]}]], "Input",
 CellLabel->"In[23]:=",
 CellID->821536295],

Cell[BoxData[
 RowBox[{
  OverscriptBox["N", "^"], "\[Rule]", 
  RowBox[{
   SuperscriptBox[
    OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
   OverscriptBox["a", "^"]}]}]], "Output",
 ImageSize->{59, 17},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->328404901]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule6", "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
    OverscriptBox["a", "^"]}], "\[Rule]", 
   OverscriptBox["N", "^"]}]}]], "Input",
 CellLabel->"In[24]:=",
 CellID->109799321],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
   OverscriptBox["a", "^"]}], "\[Rule]", 
  OverscriptBox["N", "^"]}]], "Output",
 ImageSize->{59, 17},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[24]=",
 CellID->282921413]
}, Open  ]],

Cell["\<\
Rule 7 derives a Commutator rule for the Annihilation and Creation Operators.\
\>", "Text",
 CellID->44274564],

Cell["\<\
After this the Hamiltonian is simplified using both Operator definitions.\
\>", "Text",
 CellID->387315635],

Cell["\<\
And finally a Eigenvalue - Eigenket - Relation is adopted for the Number \
Operator.\
\>", "Text",
 CellID->36085739],

Cell["Commutator rule for the Annihilation and Creation Operators", \
"MathCaption",
 CellID->432252910],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule7", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"[", 
     RowBox[{
      OverscriptBox["a", "^"], ",", 
      SuperscriptBox[
       OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "-"], "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       RowBox[{"[", 
        RowBox[{
         OverscriptBox["a", "^"], ",", 
         SuperscriptBox[
          OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "-"], "/.", 
      "rule1"}], "//", "QACommutatorExpand"}], ")"}]}]}]], "Input",
 CellLabel->"In[25]:=",
 CellID->7061275],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"[", 
    RowBox[{
     OverscriptBox["a", "^"], ",", 
     SuperscriptBox[
      OverscriptBox["a", "^"], "\[Dagger]"]}], "]"}], "-"], "\[Rule]", 
  OverscriptBox["1", "^"]}]], "Output",
 ImageSize->{79, 20},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[25]=",
 CellID->16010193]
}, Open  ]],

Cell["Simplified Hamiltonian", "MathCaption",
 CellID->202005193],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        OverscriptBox["H", "^"], "/.", "rule2"}], "//", "QAPowerExpand"}], "//",
       "FullSimplifyAss"}], ")"}], "/.", "rule3"}], "/.", "rule7"}], "//", 
  "QAExpandAll"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->118653171],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]", " ", "\[HBar]", " ", 
   RowBox[{
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
    OverscriptBox["a", "^"]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[Omega]", " ", "\[HBar]", " ", 
   OverscriptBox["1", "^"]}]}]], "Output",
 ImageSize->{110, 32},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]=",
 CellID->36448407]
}, Open  ]],

Cell["Eigenvalue - Eigenket - Relation for the Number Operator", "MathCaption",
 CellID->211679826],

Cell[BoxData[
 RowBox[{"QASet", "[", 
  RowBox[{
   RowBox[{
    OverscriptBox["N", "^"], "\[CenterDot]", 
    TagBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["n_",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}],
     Ket,
     BaseStyle->"KetWrapper"]}], "=", 
   RowBox[{"n", " ", 
    TagBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}],
     Ket,
     BaseStyle->"KetWrapper"]}]}], "]"}]], "Input",
 CellLabel->"In[28]:=",
 CellID->428358388],

Cell["\<\
Finally we derive the meaning of the Annihilation and Creation Operators, \
respectively.\
\>", "Text",
 CellID->295719031],

Cell[TextData[{
 "It becomes apparent that Annihilation / Creation Operator, applied to an \
Eigenket of ",
 Cell[BoxData[
  OverscriptBox["N", "^"]]],
 " give a new Eigenket with Eigenvalue decreased / increased by one. It also \
justifies the term Number Operator for ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["N", "^"], "."}]]]
}], "Text",
 CellID->459929078],

Cell["With this demonstration we conclude this little sample.", "Text",
 CellID->40677064],

Cell["Meaning of Annihilation and Creation Operators", "MathCaption",
 CellID->38873772],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        OverscriptBox["N", "^"], "\[CenterDot]", 
        SuperscriptBox[
         OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
        TagBox[
         RowBox[{
          AdjustmentBox["\[VerticalSeparator]",
           BoxMargins->{{-0.4, 0}, {0, 0}}], 
          AdjustmentBox[
           TagBox["n",
            QuantumAlgebra`QuantumNotation`KetArgs,
            BaseStyle->"BraKetArg"],
           BoxBaselineShift->0], "\[RightAngleBracket]"}],
         Ket,
         BaseStyle->"KetWrapper"]}], "/.", "rule5"}], ")"}], "/.", "rule3"}], 
    ")"}], "/.", "rule6"}], "/.", "rule7"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->202420052],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
   TagBox[
    RowBox[{
     AdjustmentBox["\[VerticalSeparator]",
      BoxMargins->{{-0.4, 0}, {0, 0}}], 
     AdjustmentBox[
      TagBox["n",
       QuantumAlgebra`QuantumNotation`KetArgs,
       BaseStyle->"BraKetArg"],
      BoxBaselineShift->0], "\[RightAngleBracket]"}],
    Ket,
    BaseStyle->"KetWrapper"]}], "+", 
  RowBox[{"n", " ", 
   RowBox[{
    SuperscriptBox[
     OverscriptBox["a", "^"], "\[Dagger]"], "\[CenterDot]", 
    TagBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}],
     Ket,
     BaseStyle->"KetWrapper"]}]}]}]], "Output",
 ImageSize->{123, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->705456028]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        OverscriptBox["N", "^"], "\[CenterDot]", 
        OverscriptBox["a", "^"], "\[CenterDot]", 
        TagBox[
         RowBox[{
          AdjustmentBox["\[VerticalSeparator]",
           BoxMargins->{{-0.4, 0}, {0, 0}}], 
          AdjustmentBox[
           TagBox["n",
            QuantumAlgebra`QuantumNotation`KetArgs,
            BaseStyle->"BraKetArg"],
           BoxBaselineShift->0], "\[RightAngleBracket]"}],
         Ket,
         BaseStyle->"KetWrapper"]}], "/.", "rule5"}], ")"}], "/.", "rule4"}], 
    ")"}], "/.", "rule6"}], "/.", "rule7"}]], "Input",
 CellLabel->"In[30]:=",
 CellID->311576446],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["a", "^"], "\[CenterDot]", 
     TagBox[
      RowBox[{
       AdjustmentBox["\[VerticalSeparator]",
        BoxMargins->{{-0.4, 0}, {0, 0}}], 
       AdjustmentBox[
        TagBox["n",
         QuantumAlgebra`QuantumNotation`KetArgs,
         BaseStyle->"BraKetArg"],
        BoxBaselineShift->0], "\[RightAngleBracket]"}],
      Ket,
      BaseStyle->"KetWrapper"]}], ")"}]}], "+", 
  RowBox[{"n", " ", 
   RowBox[{
    OverscriptBox["a", "^"], "\[CenterDot]", 
    TagBox[
     RowBox[{
      AdjustmentBox["\[VerticalSeparator]",
       BoxMargins->{{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox["n",
        QuantumAlgebra`QuantumNotation`KetArgs,
        BaseStyle->"BraKetArg"],
       BoxBaselineShift->0], "\[RightAngleBracket]"}],
     Ket,
     BaseStyle->"KetWrapper"]}]}]}]], "Output",
 ImageSize->{133, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",
 CellID->397069319]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[Cell[BoxData[
 ButtonBox["SetNotebookStyles",
  BaseStyle->"Link",
  ButtonData->
   "paclet:QuantumAlgebra/ref/SetNotebookStyles"]], "InlineFormula"]], \
"TutorialMoreAbout",
 CellID->141726511],

Cell[TextData[{
 ButtonBox["Bra",
  BaseStyle->"Link",
  ButtonData->"paclet:QuantumAlgebra/ref/Bra"],
 " . ",
 ButtonBox["Ket",
  BaseStyle->"Link",
  ButtonData->"paclet:QuantumAlgebra/ref/Ket"],
 " . ",
 ButtonBox["BraKet",
  BaseStyle->"Link",
  ButtonData->"paclet:QuantumAlgebra/ref/BraKet"],
 " . ",
 Cell[BoxData[
  ButtonBox["Operator",
   BaseStyle->"Link",
   ButtonData->"paclet:QuantumAlgebra/ref/Operator"]], "InlineFormula"]
}], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell["Advanced Concepts", "RelatedTutorials",
 CellID->806871991]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"QuantumAlgebra Basics - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2016, 5, 31, 18, 15, 28.4493583}", "context" -> 
    "QuantumAlgebra`", "keywords" -> {"QuantumAlgebra"}, "index" -> True, 
    "label" -> "Quantum Algebra Package Tutorial", "language" -> "en", 
    "paclet" -> "QuantumAlgebra Package", "status" -> "None", "summary" -> 
    "This tutorial introduces some of the basic principles how to enter \
Quantum objects and how to perform operations on them. First one must load \
the QuantumAlgebra application by using the Needs command. This loads the \
package", "synonyms" -> {}, "title" -> "QuantumAlgebra Basics", "type" -> 
    "Tutorial", "uri" -> "QuantumAlgebra/tutorial/QuantumAlgebraBasics"}, 
  "LinkTrails" -> "", "SearchTextTranslated" -> ""},
FrontEndVersion->"10.2 for Microsoft Windows (64-bit) (July 7, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell["Bra Ket Styles", "Section"], 
   Cell[" The cells below define certain styles needed for defining \
Bras&Kets.These styles serve to give the correct structural properties to \
Bras & Kets ", "Text"], 
   Cell[
    StyleData["BraKetArg"], SpanMinSize -> Automatic, StyleMenuListing -> 
    None, AdjustmentBoxOptions -> {BoxMargins -> {{0, 0}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> True, Selectable -> True}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> "UnmatchedBracket"}], 
   Cell[
    StyleData["BraWrapper"], ScriptBaselineShifts -> {0.6, 0.9}, SpanMinSize -> 
    2, StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{0.2, -0.13}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> None}], 
   Cell[
    StyleData["KetWrapper"], ScriptBaselineShifts -> {0.6, 0.9}, SpanMinSize -> 
    2, StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{-0.1, 0.2}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> None}], 
   Cell[
    StyleData["BraKetWrapper"], ScriptBaselineShifts -> {0.6, 0.9}, 
    SpanMinSize -> 2, StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{0.25, 0.25}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> None}], 
   Cell[
    StyleData["RIndex"], StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{-0.16, 0}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}], 
   Cell[
    StyleData["LIndex"], StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{0, -0.1}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}]}, Visible -> False, FrontEndVersion -> 
  "10.2 for Microsoft Windows (64-bit) (July 7, 2015)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[615, 21, 78, 1, 3, "TutorialColorBar"],
Cell[696, 24, 194, 5, 19, "LinkTrail"],
Cell[893, 31, 2564, 59, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3482, 94, 58, 1, 47, "Title",
 CellID->509267359],
Cell[3543, 97, 168, 4, 48, "Text",
 CellID->1534169418],
Cell[CellGroupData[{
Cell[3736, 105, 96, 1, 54, "Subsection",
 CellID->65243614],
Cell[3835, 108, 121, 3, 30, "Text",
 CellID->55229358],
Cell[3959, 113, 65, 1, 31, "MathCaption",
 CellID->229374591],
Cell[4027, 116, 124, 3, 28, "Input",
 CellID->379718389],
Cell[4154, 121, 331, 8, 66, "Text",
 CellID->165222698],
Cell[4488, 131, 172, 4, 48, "Text",
 CellID->484100602],
Cell[4663, 137, 128, 4, 30, "Text",
 CellID->520459910],
Cell[4794, 143, 90, 1, 31, "MathCaption",
 CellID->437090803],
Cell[4887, 146, 108, 3, 28, "Input",
 CellID->545952833],
Cell[4998, 151, 199, 5, 57, "DefinitionBox",
 CellID->2096742444],
Cell[5200, 158, 76, 1, 31, "Caption",
 CellID->369353387]
}, Open  ]],
Cell[CellGroupData[{
Cell[5313, 164, 61, 1, 62, "Section",
 CellID->934999218],
Cell[5377, 167, 122, 3, 30, "Text",
 CellID->313602936],
Cell[5502, 172, 128, 4, 30, "Text",
 CellID->156195064],
Cell[5633, 178, 280, 6, 70, "Text",
 CellID->880376275],
Cell[5916, 186, 107, 3, 70, "Text",
 CellID->147943834],
Cell[6026, 191, 1025, 32, 70, "DefinitionBox",
 CellID->502616482],
Cell[7054, 225, 67, 1, 70, "Caption",
 CellID->433915648],
Cell[7124, 228, 82, 1, 70, "MathCaption",
 CellID->6003686],
Cell[7209, 231, 689, 11, 241, "Output",
 CellID->8336969],
Cell[7901, 244, 88, 1, 70, "MathCaption",
 CellID->836781195],
Cell[CellGroupData[{
Cell[8014, 249, 155, 5, 70, "Input",
 CellID->9767984],
Cell[8172, 256, 179, 6, 38, "Output",
 CellID->326111295]
}, Open  ]],
Cell[CellGroupData[{
Cell[8388, 267, 152, 5, 70, "Input",
 CellID->295000522],
Cell[8543, 274, 675, 24, 36, "Output",
 CellID->176623231]
}, Open  ]],
Cell[9233, 301, 121, 3, 70, "MathCaption",
 CellID->473867497],
Cell[9357, 306, 677, 22, 70, "Input",
 CellID->253465109],
Cell[10037, 330, 1073, 33, 70, "Input",
 CellID->178066247],
Cell[11113, 365, 102, 2, 70, "MathCaption",
 CellID->56436755],
Cell[CellGroupData[{
Cell[11240, 371, 642, 22, 70, "Input",
 CellID->212963039],
Cell[11885, 395, 729, 25, 36, "Output",
 CellID->35879172]
}, Open  ]],
Cell[CellGroupData[{
Cell[12651, 425, 993, 33, 70, "Input",
 CellID->77836706],
Cell[13647, 460, 1081, 36, 39, "Output",
 CellID->17954646]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14777, 502, 64, 1, 70, "Section",
 CellID->587363850],
Cell[14844, 505, 144, 4, 70, "Text",
 CellID->374249813],
Cell[CellGroupData[{
Cell[15013, 513, 70, 1, 70, "Subsection",
 CellID->33620847],
Cell[15086, 516, 196, 4, 70, "Text",
 CellID->735022179],
Cell[15285, 522, 295, 9, 70, "DefinitionBox",
 CellID->358456651],
Cell[15583, 533, 125, 3, 70, "Caption",
 CellID->1891092685],
Cell[15711, 538, 74, 1, 70, "MathCaption",
 CellID->169278472],
Cell[15788, 541, 1393, 44, 70, "Input",
 CellID->223821793],
Cell[CellGroupData[{
Cell[17206, 589, 1489, 49, 70, "Input",
 CellID->628528297],
Cell[18698, 640, 158, 5, 36, "Output",
 CellID->19540070]
}, Open  ]],
Cell[CellGroupData[{
Cell[18893, 650, 1278, 44, 70, "Input",
 CellID->829276182],
Cell[20174, 696, 159, 5, 36, "Output",
 CellID->356632697]
}, Open  ]],
Cell[CellGroupData[{
Cell[20370, 706, 1440, 48, 70, "Input",
 CellID->528025387],
Cell[21813, 756, 159, 5, 36, "Output",
 CellID->209030887]
}, Open  ]],
Cell[CellGroupData[{
Cell[22009, 766, 1278, 44, 70, "Input",
 CellID->693483989],
Cell[23290, 812, 159, 5, 36, "Output",
 CellID->391276511]
}, Open  ]],
Cell[CellGroupData[{
Cell[23486, 822, 1582, 51, 70, "Input",
 CellID->597996886],
Cell[25071, 875, 222, 7, 36, "Output",
 CellID->22716009]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25342, 888, 71, 1, 70, "Subsection",
 CellID->30976998],
Cell[25416, 891, 243, 5, 70, "Text",
 CellID->415773475],
Cell[25662, 898, 120, 3, 70, "Text",
 CellID->862903444],
Cell[25785, 903, 319, 6, 70, "DefinitionBox",
 CellID->151152663],
Cell[26107, 911, 75, 1, 70, "Caption",
 CellID->99518789],
Cell[26185, 914, 87, 1, 70, "MathCaption",
 CellID->285879248],
Cell[26275, 917, 458, 14, 70, "Input",
 CellID->459423626],
Cell[26736, 933, 285, 6, 70, "Text",
 CellID->224802088],
Cell[27024, 941, 91, 1, 70, "MathCaption",
 CellID->190116851],
Cell[27118, 944, 265, 7, 70, "Input",
 CellID->95552490],
Cell[CellGroupData[{
Cell[27408, 955, 407, 15, 70, "Input",
 CellID->275423488],
Cell[27818, 972, 421, 15, 58, "Output",
 CellID->18531809]
}, Open  ]],
Cell[28254, 990, 240, 6, 70, "Input",
 CellID->21827284],
Cell[28497, 998, 329, 11, 70, "Input",
 CellID->218097565],
Cell[28829, 1011, 206, 6, 70, "Input",
 CellID->75068386],
Cell[CellGroupData[{
Cell[29060, 1021, 170, 6, 70, "Input",
 CellID->64153344],
Cell[29233, 1029, 179, 6, 36, "Output",
 CellID->10298058]
}, Open  ]],
Cell[29427, 1038, 260, 7, 70, "Input",
 CellID->191018353],
Cell[CellGroupData[{
Cell[29712, 1049, 172, 6, 70, "Input",
 CellID->498544831],
Cell[29887, 1057, 180, 6, 36, "Output",
 CellID->54067020]
}, Open  ]],
Cell[30082, 1066, 543, 11, 70, "Text",
 CellID->232292278],
Cell[30628, 1079, 71, 1, 70, "MathCaption",
 CellID->323211167],
Cell[30702, 1082, 392, 8, 70, "Input",
 CellID->717936233],
Cell[31097, 1092, 1345, 39, 70, "Input",
 CellID->322602097],
Cell[32445, 1133, 385, 9, 70, "Input",
 InitializationCell->True,
 CellID->51631347],
Cell[CellGroupData[{
Cell[32855, 1146, 320, 11, 70, "Input",
 CellID->354816522],
Cell[33178, 1159, 1261, 47, 62, "Output",
 CellID->147246005]
}, Open  ]],
Cell[34454, 1209, 294, 7, 70, "Input",
 CellID->13352499],
Cell[CellGroupData[{
Cell[34773, 1220, 435, 14, 70, "Input",
 CellID->117576209],
Cell[35211, 1236, 1264, 46, 62, "Output",
 CellID->32445800]
}, Open  ]],
Cell[36490, 1285, 277, 7, 70, "Input",
 CellID->220241553],
Cell[CellGroupData[{
Cell[36792, 1296, 305, 10, 70, "Input",
 CellID->545649329],
Cell[37100, 1308, 611, 21, 39, "Output",
 CellID->95657832]
}, Open  ]],
Cell[CellGroupData[{
Cell[37748, 1334, 304, 10, 70, "Input",
 CellID->24585273],
Cell[38055, 1346, 637, 22, 39, "Output",
 CellID->480176075]
}, Open  ]],
Cell[CellGroupData[{
Cell[38729, 1373, 270, 9, 70, "Input",
 CellID->821536295],
Cell[39002, 1384, 326, 11, 38, "Output",
 CellID->328404901]
}, Open  ]],
Cell[CellGroupData[{
Cell[39365, 1400, 270, 9, 70, "Input",
 CellID->109799321],
Cell[39638, 1411, 326, 11, 38, "Output",
 CellID->282921413]
}, Open  ]],
Cell[39979, 1425, 120, 3, 70, "Text",
 CellID->44274564],
Cell[40102, 1430, 117, 3, 70, "Text",
 CellID->387315635],
Cell[40222, 1435, 127, 4, 70, "Text",
 CellID->36085739],
Cell[40352, 1441, 104, 2, 70, "MathCaption",
 CellID->432252910],
Cell[CellGroupData[{
Cell[40481, 1447, 577, 20, 70, "Input",
 CellID->7061275],
Cell[41061, 1469, 368, 13, 41, "Output",
 CellID->16010193]
}, Open  ]],
Cell[41444, 1485, 65, 1, 70, "MathCaption",
 CellID->202005193],
Cell[CellGroupData[{
Cell[41534, 1490, 339, 12, 70, "Input",
 CellID->118653171],
Cell[41876, 1504, 449, 14, 53, "Output",
 CellID->36448407]
}, Open  ]],
Cell[42340, 1521, 99, 1, 70, "MathCaption",
 CellID->211679826],
Cell[42442, 1524, 860, 29, 70, "Input",
 CellID->428358388],
Cell[43305, 1555, 133, 4, 70, "Text",
 CellID->295719031],
Cell[43441, 1561, 366, 11, 70, "Text",
 CellID->459929078],
Cell[43810, 1574, 90, 1, 70, "Text",
 CellID->40677064],
Cell[43903, 1577, 88, 1, 70, "MathCaption",
 CellID->38873772],
Cell[CellGroupData[{
Cell[44016, 1582, 769, 24, 70, "Input",
 CellID->202420052],
Cell[44788, 1608, 1031, 35, 36, "Output",
 CellID->705456028]
}, Open  ]],
Cell[CellGroupData[{
Cell[45856, 1648, 730, 23, 70, "Input",
 CellID->311576446],
Cell[46589, 1673, 1030, 35, 39, "Output",
 CellID->397069319]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47680, 1715, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[47748, 1718, 209, 6, 70, "TutorialMoreAbout",
 CellID->141726511],
Cell[47960, 1726, 485, 18, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[48482, 1749, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[48557, 1752, 65, 1, 70, "RelatedTutorials",
 CellID->806871991]
}, Open  ]]
}, Open  ]],
Cell[48649, 1757, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)
